@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-08-19 19:18:55
+@LastEditTime: 2021-08-25 18:20:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -233,13 +233,12 @@ class UserAssetListHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
         act_id = int(self.get_param("act_id", 0))
         tb_user_id = int(self.get_param("tb_user_id", 0))
         asset_type = int(self.get_param("asset_type", 0))
 
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_user_asset_list(app_id, act_id, tb_user_id, asset_type, open_id))
+        return self.response_json_success(asset_base_model.get_user_asset_list(app_id, act_id, tb_user_id, asset_type))
 
 
 class AssetLogListHandler(TaoBaseHandler):
@@ -272,44 +271,6 @@ class AssetLogListHandler(TaoBaseHandler):
         return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, tb_user_id, asset_object_id, "", "", "", open_id, 0, ""))
 
 
-class PrizeRosterListHandler(TaoBaseHandler):
-    """
-    :description: 用户中奖记录列表
-    """
-    @filter_check_params("act_id,tb_user_id")
-    def get_async(self):
-        """
-        :description: 用户中奖记录列表
-        :param act_id：活动标识
-        :param user_id：用户标识
-        :param order_no：订单号
-        :param goods_type：物品类型（1虚拟2实物）
-        :param prize_type：奖品类型(1现货2优惠券3红包4参与奖5预售)
-        :param logistics_status：物流状态（0未发货1已发货2不予发货）
-        :param prize_status：奖品状态（0未下单（未领取）1已下单（已领取）2已回购10已隐藏（删除）11无需发货）
-        :param pay_status：支付状态(0未支付1已支付2已退款3处理中)
-        :param page_size：页大小
-        :param page_index：页索引
-        :return PageInfo
-        :last_editors: HuangJianYi
-        """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
-        act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
-        order_no = self.get_param("order_no")
-        goods_type = int(self.get_param("goods_type",-1))
-        prize_type = int(self.get_param("prize_type", -1))
-        logistics_status = int(self.get_param("logistics_status", -1))
-        prize_status = int(self.get_param("prize_status", -1))
-        pay_status = int(self.get_param("pay_status", -1))
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
-
-        order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, tb_user_id, open_id, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index))
-
-
 class GetJoinMemberUrlHandler(TaoBaseHandler):
     """
     :description: 获取加入会员地址
@@ -333,27 +294,3 @@ class GetJoinMemberUrlHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-
-class HorseracelampListHandler(TaoBaseHandler):
-    """
-    :description: 获取跑马灯奖品列表
-    """
-    @filter_check_params("act_id")
-    def get_async(self):
-        """
-        :description: 获取跑马灯奖品列表
-        :param act_id: 活动标识
-        :param module_id: 活动模块标识
-        :param page_size: 条数
-        :return:
-        :last_editors: HuangJianYi
-        """
-        app_id = self.get_taobao_param().source_app_id
-        act_id = int(self.get_param("act_id", 0))
-        module_id = int(self.get_param("module_id", -1))
-        page_size = int(self.get_param("page_size", 10))
-
-        if not app_id or not act_id:
-            return self.response_json_success({"data": []})
-        user_base_model = UserBaseModel(context=self)
-        return self.response_json_success(user_base_model.get_horseracelamp_list(act_id, module_id, page_size))
\ No newline at end of file
