@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-08-19 15:03:40
+@LastEditTime: 2021-08-26 18:05:41
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -177,7 +177,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         result = False, ""
         if object_id and handler_name and app_id:
-            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}", expire):
+            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}", expire) == True:
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
@@ -210,7 +210,7 @@ class FrameBaseHandler(BaseApiHandler):
             cache_key = f"request_user_list:{app_id}_{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
         else:
             key_list = []
-            for i in  current_limit_minute:
+            for i in range(current_limit_minute):
                 now_minute_int = int((datetime.datetime.now() + datetime.timedelta(minutes=-i)).strftime('%Y%m%d%H%M'))
                 key = f"request_user_list:{app_id}_{str(now_minute_int)}"
                 key_list.append(key)
@@ -235,19 +235,10 @@ class FrameBaseHandler(BaseApiHandler):
         app_secret = config.get_value("app_secret")
 
         if request_app_key not in (0, app_key):
-            cache_key = f"middler_product:requestappkey_{request_app_key}"
-            redis_init = SevenHelper.redis_init()
-            middler_product_dict = redis_init.get(cache_key)
-            if not middler_product_dict:
-                middler_product_dict = MiddlerProductModel(context=self).get_dict("app_key=%s", field="app_secret", params=request_app_key)
-                if middler_product_dict:
-                    redis_init.set(cache_key, SevenHelper.json_dumps(middler_product_dict), ex=config.get_value("cache_expire", 60 * 10))
-            else:
-                middler_product_dict = json.loads(middler_product_dict)
+            middler_product_dict = MiddlerProductModel(context=self).get_cache_dict("app_key=%s", field="app_secret", params=[request_app_key])
             if middler_product_dict:
                 app_key = request_app_key
                 app_secret = middler_product_dict["app_secret"]
-
         return app_key, app_secret
 
 
@@ -384,7 +375,7 @@ class TaoBaseHandler(FrameBaseHandler):
     def get_live_url(self, app_id):
         """
         :description: 获取live_url
-        :param app_id:app_id
+        :param app_id:应用标识
         :return str
         :last_editors: HuangJianYi
         """
@@ -421,8 +412,8 @@ class TaoBaseHandler(FrameBaseHandler):
         operation_log.operation_type = operation_type
         operation_log.model_name = model_name
         operation_log.handler_name = handler_name
-        operation_log.detail = old_detail
-        operation_log.update_detail = update_detail
+        operation_log.detail = old_detail if old_detail else {}
+        operation_log.update_detail = update_detail if update_detail else {}
         operation_log.operate_user_id = operate_user_id
         operation_log.operate_user_name = operate_user_name
 
@@ -435,6 +426,7 @@ class TaoBaseHandler(FrameBaseHandler):
 
         operation_log_model.add_entity(operation_log)
 
+
 class WeChatBaseHandler(FrameBaseHandler):
     """
     :description: 微信handler基类
