@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-08-13 18:10:40
+@LastEditTime: 2021-08-25 09:31:21
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -16,7 +16,7 @@ import ast
 
 class SevenHelper:
     """
-    :description: 常用帮助类
+    :description: 常用帮助类 提供常用方法 如：字典列表合并、请求太频繁校验、（入队列、出队列、校验队列长度 主要用于流量削峰场景）、创建分布式锁、释放分布式锁、序列化、反序列化、生成订单号等
     """
     @classmethod
     def redis_init(self, db=None, decode_responses=True):
@@ -93,7 +93,7 @@ class SevenHelper:
     @classmethod
     def redis_acquire_lock(self, lock_name, acquire_time=10, time_out=15):
         """
-        :description: 获取一个分布式锁
+        :description: 创建分布式锁
         :param lock_name：锁定名称
         :param acquire_time: 客户端等待获取锁的时间,单位秒
         :param time_out: 锁的超时时间,单位秒
@@ -117,7 +117,7 @@ class SevenHelper:
     @classmethod
     def redis_release_lock(self, lock_name, identifier):
         """
-        :description: 释放一个锁
+        :description: 释放分布式锁
         :param lock_name：锁定名称
         :param identifier: identifier
         :return bool
@@ -183,7 +183,7 @@ class SevenHelper:
         :param s_model：需要映射的实体对象
         :param map_dict：被映射的实体字典
         :return: obj
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         '''
         if map_dict:
             field_list = s_model.get_field_list()
@@ -251,7 +251,7 @@ class SevenHelper:
         :description: 文件大小格式化
         :param size：文件大小
         :return: str
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         if size < 1000:
             return '%i' % size + 'size'
@@ -300,7 +300,7 @@ class SevenHelper:
         :description: 随机取得字符串
         :param trimChars：根据什么符号进行分割
         :return: str
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         if random_str == "":
             return ""
@@ -312,7 +312,7 @@ class SevenHelper:
         """
         :description: 获取当前时间
         :return: str
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         add_hours = config.get_value("add_hours", 0)
         return TimeHelper.add_hours_by_format_time(hour=add_hours)
