@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-08-19 11:32:26
+@LastEditTime: 2021-08-26 10:28:43
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -17,7 +17,7 @@ from seven_cloudapp_frame.models.seven_model import *
 
 class AssetBaseModel():
     """
-    :description: 资产管理基类
+    :description: 资产管理业务模型
     """
     def __init__(self, context):
         self.context = context
@@ -281,19 +281,18 @@ class AssetBaseModel():
 
         return invoke_result_data
 
-    def get_user_asset_list(self, app_id, act_id, user_ids, asset_type=0, open_ids="", sub_table=None):
+    def get_user_asset_list(self, app_id, act_id, user_ids, asset_type=0, sub_table=None):
         """
         :description: 获取用户资产列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_ids：用户标识 多个逗号,分隔
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
-        :param open_ids：open_ids 多个逗号,分隔
         :param sub_table：分表名称
         :return: 返回list
         :last_editors: HuangJianYi
         """
-        if not act_id or (not user_ids and not open_ids):
+        if not act_id or not user_ids:
             return []
         condition = "act_id=%s"
         params = [act_id]
@@ -302,17 +301,12 @@ class AssetBaseModel():
             params.append(asset_type)
         if user_ids:
             if ',' in str(user_ids):
-                condition += " AND user_id in(%s)"
+                condition += f" AND user_id in ({user_ids})"
+            elif isinstance(user_ids,list):
+                condition+=" AND" + SevenHelper.get_condition_by_int_list("user_id",user_ids)
             else:
                 condition += " AND user_id=%s"
-            params.append(user_ids)
-        if open_ids:
-            if ',' in str(open_ids):
-                condition += " AND open_id in(%s)"
-            else:
-                condition += " AND open_id=%s"   
-            params.append(open_ids)
-
+                params.append(user_ids)
         user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
