@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-08-19 15:04:33
+@LastEditTime: 2021-08-26 10:37:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_framework import *
 
 class FrameBaseModel():
     """
-    :description: 框架业务模型基类
+    :description: 框架业务模型 用于被其他业务模型继承，调用模型之间通用的方法
     """
     def __init__(self, context):
         self.context = context
@@ -101,8 +101,8 @@ class FrameBaseModel():
     def get_order_status_name(self, order_status):
         """
         :description: 获取订单状态名称 -1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功
-        :param status_id：状态id
-        :return str
+        :param order_status：订单状态
+        :return 订单状态名称
         :last_editors: HuangJianYi
         """
         if order_status == -1:
@@ -146,7 +146,7 @@ class FrameBaseModel():
         
         #请求太频繁限制
         if continue_request_expire > 0:
-            if SevenHelper.is_continue_request(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}",expire=continue_request_expire) == False:
+            if SevenHelper.is_continue_request(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}",expire=continue_request_expire*1000) == True:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
@@ -161,14 +161,16 @@ class FrameBaseModel():
             return invoke_result_data
 
         now_date = SevenHelper.get_now_datetime()
+        act_info_dict["start_date"] = str(act_info_dict["start_date"])
+        act_info_dict["end_date"] = str(act_info_dict["end_date"])
         if act_info_dict["start_date"] != "" and act_info_dict["start_date"] != "1900-01-01 00:00:00":
-            if TimeHelper.format_time_to_datetime(now_date) < act_info_dict['start_date']:
+            if now_date < act_info_dict["start_date"]:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "活动将在" + str(act_info_dict['start_date']) + "开启"
+                invoke_result_data.error_message = "活动将在" + act_info_dict['start_date'] + "开启"
                 return invoke_result_data
         if act_info_dict["end_date"] != "" and act_info_dict["end_date"] != "1900-01-01 00:00:00":
-            if TimeHelper.format_time_to_datetime(now_date) > act_info_dict['end_date']:
+            if now_date > act_info_dict["end_date"]:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "活动已结束"
@@ -182,14 +184,16 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "no_module"
                 invoke_result_data.error_message = "活动信息不存在"
                 return invoke_result_data
-            if act_module_dict['start_date'] != "" and act_module_dict['start_date'] != "1900-01-01 00:00:00":
-                if TimeHelper.format_time_to_datetime(now_date) < act_module_dict['start_date']:
+            act_module_dict["start_date"] = str(act_module_dict["start_date"])
+            act_module_dict["end_date"] = str(act_module_dict["end_date"])
+            if act_module_dict["start_date"] != "" and act_module_dict["start_date"] != "1900-01-01 00:00:00":
+                if now_date < act_module_dict["start_date"]:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "活动将在" + str(act_module_dict['start_date']) + "开启"
+                    invoke_result_data.error_message = "活动将在" + act_module_dict["start_date"] + "开启"
                     return invoke_result_data
-            if act_module_dict['end_date'] != "" and act_module_dict['end_date'] != "1900-01-01 00:00:00":
-                if TimeHelper.format_time_to_datetime(now_date) > act_module_dict['end_date']:
+            if act_module_dict["end_date"] != "" and act_module_dict["end_date"] != "1900-01-01 00:00:00":
+                if now_date > act_module_dict["end_date"]:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "活动已结束"
