@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-08-17 15:39:30
+@LastEditTime: 2021-08-26 10:30:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
 
 class StatBaseModel():
     """
-    :description: 统计上报基类
+    :description: 统计上报业务模型
     """
     def __init__(self, context):
         self.context = context
