@@ -1,22 +1,20 @@
 # -*- coding: utf-8 -*-
 """
-:Author: HuangJingCan
+:Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-08-19 21:19:25
+@LastEditTime: 2021-08-26 10:30:18
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
-from typing import Set
 from seven_top import top
-
 from seven_cloudapp_frame.models.db_models.base.base_info_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
 from seven_cloudapp_frame.models.seven_model import *
 
 class TopBaseModel():
     """
-    :description: 淘宝top接口基类
+    :description: 淘宝top接口业务模型
     """
     def __init__(self,context):
         self.context = context
@@ -441,7 +439,7 @@ class TopBaseModel():
         :param app_secret:app_secret
         :param is_log：是否记录返回信息
         :return InvokeResultData
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         try:
@@ -518,7 +516,7 @@ class TopBaseModel():
         :param app_secret：app_secret
         :param is_log：是否记录返回信息
         :return: InvokeResultData
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         try:
@@ -597,7 +595,7 @@ class TopBaseModel():
         :param fields：返回字段
         :param is_log：是否记录返回信息
         :return InvokeResultData
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
 
