@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-08-19 15:59:16
+@LastEditTime: 2021-08-26 10:30:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -18,7 +18,7 @@ from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 
 class UserBaseModel():
     """
-    :description: 用户信息基类
+    :description: 用户信息业务模型
     """
     def __init__(self, context):
         self.context = context
@@ -199,10 +199,9 @@ class UserBaseModel():
                 user_account.modify_date = now_datetime
                 user_account.id = user_account_model.add_entity(user_account)
             else:
-                if user_account.user_nick != user_nick or user_account.avatar != avatar:
-                    user_account.user_nick = user_nick
-                    user_account.avatar = avatar
-                    user_account_model.update_entity(user_account, "user_nick,avatar")
+                user_account.user_nick = user_nick if user_nick and user_account.user_nick != user_nick else user_account.user_nick
+                user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
+                user_account_model.update_entity(user_account, "user_nick,avatar")
                 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
@@ -666,81 +665,4 @@ class UserBaseModel():
             result = False
         return result
  
-    def get_horseracelamp_list(self,act_id,module_id,page_size=30):
-            """
-            :description: 获取跑马灯奖品列表
-            :param act_id:活动标识
-            :param module_id:活动模块标识
-            :param page_size：页大小
-            :return list
-            :last_editors: HuangJianYi
-            """
-            condition = "act_id=%s"
-            params = [act_id]
-            if module_id:
-                condition+= " and module_id=%s"
-                params.append(module_id)
-            act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_list("act_id=%s and is_prize_notice=0 and is_del=0", params=[act_id],cache_expire=60)
-            if act_prize_list_dict:
-                prize_id_list = [str(i["id"]) for i in act_prize_list_dict]
-                if len(prize_id_list) > 0:
-                    prize_ids = ",".join(prize_id_list)
-                    condition += " and prize_id not in (" + prize_ids + ")"
-            condition += f" and create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
-            prize_roster_model = PrizeRosterModel(context=self.context)
-            prize_roster_list = prize_roster_model.get_cache_dict_list(condition, "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params,cache_expire=60)
-            total = int(len(prize_roster_list))
-            if total == 0:
-                prize_roster_list = []
-            else:
-                for i in range(len(prize_roster_list)):
-                    if prize_roster_list[i]["user_nick"]:
-                        length = len(prize_roster_list[i]["user_nick"])
-                        if length > 2:
-                            user_nick = prize_roster_list[i]["user_nick"][0:length - 2] + "**"
-                        else:
-                            user_nick = prize_roster_list[i]["user_nick"][0:1] + "*"
-                        prize_roster_list[i]["user_nick"] = user_nick
-            if total < page_size:
-                module_condition = "act_id=%s and is_fictitious=1"
-                module_params = [act_id]
-                if module_id > 0:
-                    module_condition += " and id=%s"
-                    module_params = [act_id, module_id]
-                act_module_list = ActModuleModel(context=self.context).get_cache_list(module_condition, params=module_params,cache_expire=60)
-                if len(act_module_list) > 0:
-                    module_id_list = [str(i.id) for i in act_module_list]
-                    module_ids = ",".join(module_id_list)
-                    add_num = page_size - total
-                    act_prize_model = ActPrizeModel(context=self.context)
-                    prize_condition = "act_id=%s and is_prize_notice=1"
-                    prize_params = [act_id]
-                    if module_id > 0:
-                        prize_condition += " and module_id=%s"
-                        prize_params.append(module_id)
-                    else:
-                        prize_condition += " and module_id in (" + module_ids + ")"
-                    false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
-                    if len(false_act_prize_list) > 0 and add_num > 0:
-                        now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                        user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
-
-                        for i in range(len(user_info_list_dict)):
-                            false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list))]
-                            if len(false_act_prize) <= 0:
-                                continue
-                            prize_roster = {}
-                            if user_info_list_dict[i]["user_nick"]:
-                                length = len(user_info_list_dict[i]["user_nick"])
-                                if length > 2:
-                                    user_nick = user_info_list_dict[i]["user_nick"][0:length - 2] + "**"
-                                else:
-                                    user_nick = user_info_list_dict[i]["user_nick"][0:1] + "*"
-                            prize_roster["user_nick"] = user_nick
-                            prize_roster["prize_name"] = false_act_prize.prize_name
-                            prize_roster["tag_id"] = false_act_prize.tag_id
-                            act_module_filter = [act_module for act_module in act_module_list if false_act_prize.module_id == act_module.id]
-                            prize_roster["module_name"] = act_module_filter[0].module_name if len(act_module_filter) > 0 else ""
-                            prize_roster_list.append(prize_roster)
-            
-            return prize_roster_list
\ No newline at end of file
+    
\ No newline at end of file
